@@ -2,7 +2,7 @@ from pathlib import Path
 
 import alteia
 
-from alteia_cli import config
+from alteia_cli import __version__, config
 
 
 def alteia_sdk(credential_path: Path = config.DEFAULT_CREDENTIAL_PATH, *,
@@ -15,8 +15,9 @@ def alteia_sdk(credential_path: Path = config.DEFAULT_CREDENTIAL_PATH, *,
         credentials = config.setup(credential_path=credential_path)
 
     return alteia.SDK(
-            user=credentials.username,
-            password=credentials.password,
-            url=credentials.url,
-            proxy_url=credentials.proxy_url,
-        )
+        user=credentials.username,
+        password=credentials.password,
+        url=credentials.url,
+        proxy_url=credentials.proxy_url,
+        service=f'alteia-cli/{__version__}',
+    )
