@@ -1,7 +1,7 @@
 import itertools
 import pprint
 from functools import lru_cache
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union, cast
 
 import alteia
 import click_spinner
@@ -9,7 +9,7 @@ import jsonschema
 import typer
 from alteia.core.errors import ResponseError
 from alteia.core.resources.resource import Resource
-from alteia.core.utils.typing import ResourceId
+from alteia.core.utils.typing import ResourceId, SomeResourceIds
 
 # Replace default spinner with a prettier
 SPINNER = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏']
@@ -67,9 +67,12 @@ def check_json_schema(json_schema):
 
 
 @lru_cache(maxsize=32)
-def describe_company(sdk: alteia.SDK, company_id: ResourceId) -> Resource:
+def describe_company(sdk: alteia.SDK, company_id: ResourceId) -> Optional[Resource]:
     try:
-        return sdk.companies.describe(company_id)
+        return cast(
+            Resource,
+            sdk.companies.describe(cast(SomeResourceIds, company_id))
+        )
     except ResponseError:
         return None
 
